Bypass class

Annotations
  • @JsonSerializable.new()

Constructors

Bypass({bool? isCulturalExpense, String? cashReceiptType, String? acceptMethod, String? pReserved, Daou? daou, Tosspayments? tosspayments, Settle? settle, Danal? danal})
Bypass.fromJson(Map<String, dynamic> json)
factory

Properties

acceptMethod ↔ String?
getter/setter pair
cashReceiptType ↔ String?
getter/setter pair
danal ↔ Danal?
getter/setter pair
daou ↔ Daou?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isCulturalExpense ↔ bool?
getter/setter pair
pReserved ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settle ↔ Settle?
getter/setter pair
tosspayments ↔ Tosspayments?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited